@@ -21,12 +21,12 @@ use Exporter::Shiny qw(
     default_profile
 );
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 our %EXPORT_TAGS = (
-    'ini'  => [qw( read_file read_string read_handle )],
-    'aws'  => [qw( config_file default_profile credentials_file )],
-    'read' => [qw( read read_all list_profiles )],
-    'all'  => [qw( :ini :aws :read )],
+    ini  => [qw( read_file read_string read_handle )],
+    aws  => [qw( config_file default_profile credentials_file )],
+    read => [qw( read read_all list_profiles )],
+    all  => [qw( :ini :aws :read )],
 );
 
 # Config parsing interface
@@ -86,7 +86,7 @@ sub read_handle {
     croak 'Handle is missing' unless @_ >= 1;
     croak 'Argument was not a handle'
         unless Scalar::Util::openhandle( $_[0] );
-    _read( [ map { chomp; $_ } shift->getlines ], @_ );
+    _read( [ map { s/\015?\012/\n/; chomp; $_ } shift->getlines ], @_ );
 }
 
 # Internal methods for parsing and validation
@@ -135,7 +135,7 @@ sub _read {
     my $nested = {};
 
     my $profile = q{};
-    foreach my $i (0 .. scalar(@{$lines}) - 1) {
+    foreach my $i (0 .. $#{$lines}) {
         my $line = $lines->[$i];
         chomp $line;
 
@@ -209,13 +209,13 @@ Config::AWS - Parse AWS config files
 
 =head1 DESCRIPTION
 
-Config::AWS is a small distribution with generic methods to correctly parse the
-contents of config files for the AWS CLI client as described in
+Config::AWS is a small distribution with generic methods to correctly parse
+the contents of config files for the AWS CLI client as described in
 L<the AWS documentation|https://docs.aws.amazon.com/cli/latest/topic/config-vars.html>.
 
-Although it is common to see these files parsed as standard INI files, this is
-not appropriate since AWS config files have an idiosyncratic format for nested
-values (as shown in the link above).
+Although it is common to see these files parsed as standard INI files, this
+is not appropriate since AWS config files have an idiosyncratic format for
+nested values (as shown in the link above).
 
 Standard INI parsers (like L<Config::INI>) are not made to parse this sort of
 structure (nor should they). So Config::AWS exists to provide a suitable
@@ -223,10 +223,10 @@ and lightweight ad-hoc parser that can be used in other applications.
 
 =head1 ROUTINES
 
-Config::AWS does not export anything by default. All the functions described
-in this document can be requested by name at the time of import. Alternatively,
-the C<:all> tag can be used to import all of them into your namespace in one
-go. Other tags are explained in the sections below.
+Config::AWS does not export anything by default. All the functions
+described in this document can be requested by name at the time of import.
+Alternatively, the C<:all> tag can be used to import all of them into your
+namespace in one go. Other tags are explained in the sections below.
 
 =head2 Parsing routines
 
@@ -252,8 +252,8 @@ imported with the C<:read> tag.
     $profile = read( $source, $profile );         # Specify source and profile
     $profile = read( undef,   $profile );         # Use default file
 
-Parse AWS config data. All these functions take the source of data to use as
-their first arugment. The source can be any of the following:
+Parse AWS config data. All these functions take the data source to use as
+their first argument. The source can be any of the following:
 
 =over 4
 
@@ -269,16 +269,16 @@ their first arugment. The source can be any of the following:
 
 =back
 
-If the source is undefined, a default file name will be used. This will be the
-result of calling B<credentials_file> (if it is a readable file) or the result
-of calling B<config_file> otherwise.
+If the source is undefined, a default file name will be used. This will be
+the result of calling B<credentials_file> (if it is a readable file) or the
+result of calling B<config_file> otherwise.
 
-B<read_all> will return the results of parsing all of the content in the source,
-for all profiles that may be defined in it.
+B<read_all> will return the results of parsing all of the content in the
+source, for all profiles that may be defined in it.
 
-B<read> will instead return the data I<for a single profile only>. This profile
-can be specified as the second argument. If no profile is provided, B<read>
-will use the result of calling B<default_profile> as the default.
+B<read> will instead return the data I<for a single profile only>. This
+profile can be specified as the second argument. If no profile is provided,
+B<read> will use the result of calling B<default_profile> as the default.
 
 B<list_profiles> will return only the names of the profiles specified in the
 config as a list. The order will be the same as that used in the source.
@@ -287,8 +287,8 @@ config as a list. The order will be the same as that used in the source.
 
 =head2 AWS defaults
 
-These routines provide information about the default values, as understood by
-the AWS CLI interface. These can be imported with the C<:aws> tag.
+These routines provide information about the default values, as understood
+by the AWS CLI interface. These can be imported with the C<:aws> tag.
 
 =over 4
 
@@ -304,8 +304,8 @@ C<~/.aws/config> if undefined.
 
 =item B<credentials_file>
 
-Returns the contents of the C<AWS_SHARED_CREDENTIALS_FILE> environment variable,
-or C<~/.aws/credentials> if undefined.
+Returns the contents of the C<AWS_SHARED_CREDENTIALS_FILE> environment
+variable, or C<~/.aws/credentials> if undefined.
 
 =back
 
@@ -313,13 +313,14 @@ or C<~/.aws/credentials> if undefined.
 
 =for Pod::Coverage read_file read_string read_handle
 
-This module includes routines that allow it to be used as a drop-in replacement
-of L<Config::INI>. The B<read_file>, B<read_string>, and B<read_handle>
-functions behave like those described in the documentation for that
-distribution. They can be imported with the C<:ini> tag.
+This module includes routines that allow it to be used as a drop-in
+replacement of L<Config::INI>. The B<read_file>, B<read_string>, and
+B<read_handle> functions behave like those described in the documentation
+for that distribution. They can be imported with the C<:ini> tag.
 
-Unlike the functions described above, they do not use the default values for
-AWS config files or profiles, and require the source to be explicitly stated.
+Unlike the functions described above, they do not use the default values
+for AWS config files or profiles, and require the source to be explicitly
+stated.
 
 To more closely mimic the behaviour of the methods they emulate, they return
 the entire parsed config data. As a concesion, an optional profile can be
